package com.ruoyi.basicData.mapper;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.basicData.domain.TCorps;
import com.ruoyi.basicData.domain.TCorps;
import com.ruoyi.basicData.domain.TCustomerContact;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 客户详情Mapper接口
 *
 * @author ruoyi
 * @date 2020-12-11
 */
public interface TCorpsMapper extends BaseMapper<TCorps> {
    /**
     * 查询客户详情
     *
     * @param fId 客户详情ID
     * @return 客户详情
     */
    public TCorps selectTCorpsById(Long fId);

    /**
     * 查询客户详情列表
     *
     * @param tCorps 客户详情
     * @return 客户详情集合
     */
    public List<TCorps> selectTCorpsList(TCorps tCorps);

    /**
     * 新增客户详情
     *
     * @param tCorps 客户详情
     * @return 结果
     */
    public int insertTCorps(TCorps tCorps);

    /**
     * 修改客户详情
     *
     * @param tCorps 客户详情
     * @return 结果
     */
    public int updateTCorps(TCorps tCorps);

    /**
     * 删除客户详情
     *
     * @param fId 客户详情ID
     * @return 结果
     */
    public int deleteTCorpsById(Long fId);

    /**
     * 批量删除客户详情
     *
     * @param fIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTCorpsByIds(Long[] fIds);

    /**
     *  检验编号唯一
     * @param fNo
     * @return
     */
    public TCorps checkFNoUnique(String fNo);

    /**
     *  检验名称
     * @param fNname
     * @return
     */
    public TCorps checkUFNnameUnique(String fNname);

    /**
     * 检验地址
     * @param fCname
     * @return
     */
    public TCorps checkUFCnameUnique(String fCname);

    /**
     *  检验登录账号
     * @param loginAccount
     * @return
     */
    public TCorps checkULoginAccountUnique(String loginAccount);

    /**
     *  查询客户列表信息
     * @param tCorps
     * @return
     */
    public List<Map<String, Object>> selectFleetDriverMsgListMap(TCorps tCorps);

    /**
     *  根据手机号查询司机信息
     * @param phonenumber   手机号
     * @return  结果
     */
    public TCorps selectTCorpsByFTel(String phonenumber);

    /**
     *  车队使用，查询客户、司机信息
     * @param fId
     * @return
     */
    public List<TCorps> selectCorpList(Long fId);

    /**
     *  车队使用，查询客户、车队信息
     * @return
     * @param tCorps
     */
    public List<TCorps> selectCustomerDriverList(TCorps tCorps);

    /**
     * 获取客户名称
     * @param tCorps
     * @return
     */
    public List<Map<String,Object>> getClientName (TCorps tCorps);

    /**
     * 获取客户单位id
     * @param tel
     * @return
     */
    public Long getClientFid(@Param("tel") String tel);

    /**
     *  根据条件查询客户200条
     * @param corps
     * @return
     */
    public List<TCorps> selectTCorpsListLimit200(TCorps corps);
    /**
     * 网页版申请发票获取发票信息
     * @param corps
     * @return
     */
    public TCorps getClientMessage(TCorps corps);
}
